@@ -1,5 +1,5 @@
 use ockam_core::hex::encode;
-use ockam_vault_core::{Hasher, SecretAttributes, SecretPersistence, SecretType, SecretVault};
+use ockam_core::vault::{Hasher, SecretAttributes, SecretPersistence, SecretType, SecretVault};
 
 pub async fn sha256(vault: &mut impl Hasher) {
     let res = vault.sha256(b"a").await;
